{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#Dockstore.cwl",
            "label": "CGP file checksum generator",
            "doc": "![build_status](https://quay.io/repository/wtsicgp/dockstore-cgp-chksum/status)\nA Docker container for producing file md5sum and sha512sum. See the [dockstore-cgp-chksum](https://github.com/cancerit/dockstore-cgp-chksum) website for more information.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-chksum:0.2.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "file to have checksum generated from",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/in_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Optional POST address to send JSON results",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p",
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/post_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "prefix": "-H",
                                "separate": true,
                                "shellQuote": true
                            }
                        }
                    ],
                    "doc": "Optional headers to send with JSON results",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/post_headers"
                }
            ],
            "baseCommand": [
                "/opt/wtsi-cgp/bin/sums2json.sh"
            ],
            "http://purl.org/dc/terms/creator": {
                "@id": "yaobo.xu@sanger.ac.uk",
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yx2@sanger.ac.uk"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).check_sums.json"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/chksum_json"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.in_file.basename).post_server_response.txt"
                    },
                    "id": "#Dockstore.cwl/cgp-chksum/post_server_response"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#cgp-seqval-qc_pairs_1.cwl",
            "label": "CGP sequence validator",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/wtsicgp/dockstore-cgp-seqval:0.1.1"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "Fastq files to verify, can be gzipped.",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1,
                        "separate": true,
                        "shellQuote": true
                    },
                    "id": "#cgp-seqval-qc_pairs_1.cwl/cgp-seqval/fastqs_in"
                },
                {
                    "type": "string",
                    "doc": "Not to be overridden by users: Output as interleaved FASTQ (ignored for interleaved input)",
                    "default": "interleaved.fq.gz",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 2,
                        "separate": true
                    },
                    "id": "#cgp-seqval-qc_pairs_1.cwl/cgp-seqval/output_fq"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "interleaved.fq.gz"
                    },
                    "id": "#cgp-seqval-qc_pairs_1.cwl/cgp-seqval/ifastq_out"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "report.json"
                    },
                    "id": "#cgp-seqval-qc_pairs_1.cwl/cgp-seqval/report_json"
                }
            ],
            "baseCommand": [
                "cgpSeqInputVal",
                "seq-valid",
                "-r",
                "report.json",
                "-q",
                "1"
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "label": "CGP checksum and interleave fastq generation workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "doc": "Gzipped fastq files to import.",
                    "id": "#main/fastq_in"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "string"
                        ]
                    },
                    "doc": "POST address to send JSON results of checksums, use list of empty strings if no POST is required.",
                    "id": "#main/post_address"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "Optional headers to send with JSON results.",
                    "id": "#main/post_headers"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3464",
                    "outputSource": "#main/chksum/chksum_json",
                    "id": "#main/chksum_json"
                },
                {
                    "type": {
                        "type": "array",
                        "items": [
                            "null",
                            "File"
                        ]
                    },
                    "outputSource": "#main/chksum/post_server_response",
                    "id": "#main/chksum_post_server_response"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputSource": "#main/interleave/ifastq_out",
                    "id": "#main/interleave_ifastq_out"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3464",
                    "outputSource": "#main/interleave/report_json",
                    "id": "#main/interleave_report_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/names_to_file/outfile",
                    "id": "#main/rg_file_names"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/rename/outfile",
                            "id": "#main/chksum/in_file"
                        },
                        {
                            "source": "#main/post_address",
                            "id": "#main/chksum/post_address"
                        },
                        {
                            "source": "#main/post_headers",
                            "id": "#main/chksum/post_headers"
                        }
                    ],
                    "out": [
                        "#main/chksum/chksum_json",
                        "#main/chksum/post_server_response"
                    ],
                    "scatter": [
                        "#main/chksum/in_file",
                        "#main/chksum/post_address"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#Dockstore.cwl",
                    "id": "#main/chksum"
                },
                {
                    "in": [
                        {
                            "source": "#main/rename/outfile",
                            "id": "#main/interleave/fastqs_in"
                        }
                    ],
                    "out": [
                        "#main/interleave/report_json",
                        "#main/interleave/ifastq_out"
                    ],
                    "run": "#cgp-seqval-qc_pairs_1.cwl",
                    "id": "#main/interleave"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/interleave/ifastq_out"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/names_to_file/files"
                        }
                    ],
                    "out": [
                        "#main/names_to_file/outfile"
                    ],
                    "run": "#echo_filenames_to_file.cwl",
                    "id": "#main/names_to_file"
                },
                {
                    "in": [
                        {
                            "source": "#main/fastq_in",
                            "valueFrom": "$(self.basename.replace(/\\.f(?:ast)?q(?:\\.gz)?/i, \"\")).fq.gz",
                            "id": "#main/rename/newname"
                        },
                        {
                            "source": "#main/fastq_in",
                            "id": "#main/rename/srcfile"
                        }
                    ],
                    "scatter": [
                        "#main/rename/srcfile",
                        "#main/rename/newname"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#main/rename/outfile"
                    ],
                    "run": "#rename.cwl",
                    "id": "#main/rename"
                }
            ],
            "doc": "A workflow to generate checksums of FastQ files and a interleaved FastQ from them. See the [workflow-seq-import](https://github.com/cancerit/workflow-seq-import) website for more information.\n",
            "http://schema.org/codeRepository": "https://github.com/cancerit/workflow-seq-import",
            "http://schema.org/license": "https://spdx.org/licenses/AGPL-3.0",
            "http://schema.org/author": [
                {
                    "class": "http://schema.org/Person",
                    "http://schema.org/email": "mailto:yyaobo@gmail.com",
                    "http://schema.org/name": "Yaobo Xu"
                }
            ],
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Yaobo Xu",
                "foaf:mbox": "yyaobo@gmail.com"
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "valueFrom": "$(self.map(f => f.basename))",
                        "itemSeparator": "\\n"
                    },
                    "id": "#echo_filenames_to_file.cwl/files"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "rg_file_names.txt"
                    },
                    "id": "#echo_filenames_to_file.cwl/outfile"
                }
            ],
            "baseCommand": [
                "echo",
                "-e"
            ],
            "stdout": "rg_file_names.txt",
            "id": "#echo_filenames_to_file.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "true",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "$(inputs.newname)",
                            "entry": "$(inputs.srcfile)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#rename.cwl/newname"
                },
                {
                    "type": "File",
                    "id": "#rename.cwl/srcfile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.newname)"
                    },
                    "id": "#rename.cwl/outfile"
                }
            ],
            "id": "#rename.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.18.owl",
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/",
        "edam": "http://edamontology.org/"
    }
}
